summaryrefslogtreecommitdiffstats
path: root/macosx/HBPreset.h
diff options
context:
space:
mode:
authorDamiano Galassi <[email protected]>2017-11-10 12:41:07 +0100
committerDamiano Galassi <[email protected]>2017-11-10 12:41:07 +0100
commit1f7aeb62b9ac51132fddc260e4193e07f056ed2f (patch)
tree6a5d34001cc93d596853b8ebf4233283098ce8cb /macosx/HBPreset.h
parent65597ee7f4bfa11838d815fceb6bc6dd24150c1f (diff)
MacGui: rename Folder to Category.
Diffstat (limited to 'macosx/HBPreset.h')
-rw-r--r--macosx/HBPreset.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/macosx/HBPreset.h b/macosx/HBPreset.h
index 7d4551fed..3e95d3bab 100644
--- a/macosx/HBPreset.h
+++ b/macosx/HBPreset.h
@@ -17,11 +17,11 @@ typedef NS_ENUM(NSUInteger, HBPresetFormat) {
* HBPreset
* Stores a preset dictionary.
*
* An instance of HBPreset can be an actual preset or a folder.
*/
@interface HBPreset : HBTreeNode <NSCopying, NSMutableCopying>
-- (instancetype)initWithFolderName:(NSString *)title builtIn:(BOOL)builtIn;
+- (instancetype)initWithCategoryName:(NSString *)title builtIn:(BOOL)builtIn;
- (instancetype)initWithName:(NSString *)title content:(NSDictionary *)content builtIn:(BOOL)builtIn;
- (instancetype)initWithDictionary:(NSDictionary *)dict;
@@ -17,11 +17,11 @@ typedef NS_ENUM(NSUInteger, HBPresetFormat) {
* Stores a preset dictionary.
*
- * An instance of HBPreset can be an actual preset or a folder.
+ * An instance of HBPreset can be an actual preset or a category.
*/